pub struct WorkspaceReleaseConfig {
pub banner: ReleaseBannerConfig,
pub header: Option<String>,
pub footer: Option<String>,
}Fields
The workspace’s release banner details or URL
header: Option<String>A header message appended to the start of the release notes
A footer message appended to the end of the release notes