pub struct WorkspaceConfig {Show 35 fields
pub schema: String,
pub config: Option<Config>,
pub config_file: Option<String>,
pub extends: Option<ExtendsConfig>,
pub workspace_root: String,
pub name: String,
pub namespace: String,
pub variant: WorkspaceVariant,
pub organization: WorkspaceOrganizationConfig,
pub repository: String,
pub license: String,
pub homepage: String,
pub docs: Option<String>,
pub portal: Option<String>,
pub licensing: Option<String>,
pub contact: Option<String>,
pub support: Option<String>,
pub branch: String,
pub preid: Option<String>,
pub owner: String,
pub bot: WorkspaceBotConfig,
pub mode: WorkspaceMode,
pub colors: WorkspaceColorsConfig,
pub release: WorkspaceReleaseConfig,
pub socials: WorkspaceSocialsConfig,
pub error: WorkspaceErrorConfig,
pub skip_cache: bool,
pub registry: WorkspaceRegistryUrlConfig,
pub directories: WorkspaceDirectoriesConfig,
pub package_manager: PackageManagerType,
pub timezone: String,
pub locale: String,
pub log_level: LogLevel,
pub skip_config_logging: bool,
pub extensions: RefCell<HashMap<String, HashMap<String, Value>>>,
}Expand description
Storm Workspace config values used during various development processes. It represents the shared config of the entire monorepo.
Fields
schema: StringThe JSON schema reference describing the workspace configuration
config: Option<Config>The configuration values parsed from the file
config_file: Option<String>The filepath of the Storm config. When this field is null, no config file was found in the current workspace.
extends: Option<ExtendsConfig>Optional configuration presets to extend from
workspace_root: StringThe root directory of the package
name: StringThe name of the package
namespace: StringThe namespace of the package
variant: WorkspaceVariantThe configured workspace variant
organization: WorkspaceOrganizationConfigThe organization configuration backing the workspace
repository: StringThe repo URL of the workspace (i.e. GitHub)
license: StringThe license used by the package
homepage: StringThe homepage of the workspace
docs: Option<String>The documentation site for the workspace
portal: Option<String>The development portal site for the workspace
licensing: Option<String>The licensing site for the workspace
contact: Option<String>The contact site for the workspace
support: Option<String>The support site for the workspace
branch: StringThe branch of the workspace
preid: Option<String>A tag specifying the version pre-release identifier
owner: StringThe owner of the package
bot: WorkspaceBotConfigThe workspace bot configuration used to automate tasks
mode: WorkspaceModeThe current workspace runtime mode (development/test/production)
colors: WorkspaceColorsConfigConfigured color settings for the workspace
release: WorkspaceReleaseConfigThe workspace release configuration
The workspace socials configuration
error: WorkspaceErrorConfigThe workspace error configuration
skip_cache: boolShould all known types of workspace caching be skipped?
registry: WorkspaceRegistryUrlConfigThe registry configuration for the workspace
directories: WorkspaceDirectoriesConfigThe directories configuration for the workspace
package_manager: PackageManagerTypeThe package manager used by the repository
timezone: StringThe default timezone of the workspace
locale: StringThe default locale of the workspace
log_level: LogLevelThe log level used to filter out lower priority log messages. If not provided, this is defaulted using the environment config value (if environment is set to production then level is error, else level is debug).
skip_config_logging: boolShould the logging of the current Storm Workspace configuration be skipped?
extensions: RefCell<HashMap<String, HashMap<String, Value>>>Configuration of each used extension
Implementations
Sourceimpl WorkspaceConfig
impl WorkspaceConfig
pub fn new() -> Result<Self, ConfigError>
pub fn from_workspace_root(workspace_root: &Path) -> Result<Self, ConfigError>
pub fn get_extension(&self, name: &str) -> Option<HashMap<String, Value>>